@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Access to the Hooktheory API
 
-our $VERSION = '0.0405';
+our $VERSION = '0.0406';
 
 use Moo;
 use strictures 2;
@@ -14,6 +14,7 @@ use Mojo::UserAgent;
 use Mojo::JSON::MaybeXS;
 use Mojo::JSON qw( decode_json );
 use Mojo::URL;
+use Try::Tiny;
 
 
 has username => (
@@ -92,12 +93,12 @@ sub _handle_response {
 
     if ( $res->is_success ) {
         my $body = $res->body;
-        if ( $body =~ /{/ ) {
-            $data = decode_json( $res->body );
+        try {
+            $data = decode_json($body);
         }
-        else {
+        catch {
             croak $body, "\n";
-        }
+        };
     }
     else {
         croak "Connection error: ", $res->message;
@@ -120,7 +121,7 @@ WebService::Hooktheory - Access to the Hooktheory API
 
 =head1 VERSION
 
-version 0.0405
+version 0.0406
 
 =head1 SYNOPSIS
 
